California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: SENATE DISTRICT 29 - SPECIAL RECALL ELECTION View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1396225 | NEWMAN OPPOSED TO THE RECALL, FRIENDS OF JOSH | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1396447 | NEWMAN, SPONSORED AND FUNDED BY NO NEW TAXES, A PROJECT OF THE HOWARD JARVIS TAXPAYERS ASSOCIATION; CALIFORNIANS AGAINST CAR AND GAS TAX HIKES, A COMMITTEE TO RECALL JOSH | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1396135 | NEWMAN, SPONSORED BY CALIFORNIA ALLIANCE FOR JOBS AND THE STATE BUILDING & CONSTRUCTION TRADES COUNCIL OF CALIFORNIA; CALIFORNIANS FOR BETTER COMMUNITIES, OPPOSING THE RECALL OF SENATOR JOSH | OPPOSE